@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-config.h.in,v 1.21 2009/05/14 20:12:17 enlf Exp $
+/* $Id: m-config.h.in,v 1.22 2010/08/28 23:44:23 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2009 by Erik Nolf
+   Copyright (C) 1997-2010 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -34,11 +34,11 @@
 /* Define some version variables */
 #define XMEDCON_MAJOR    "0"
 #define XMEDCON_MINOR    "10"
-#define XMEDCON_MICRO    "5"
+#define XMEDCON_MICRO    "7"
 #define XMEDCON_PRGR     "(X)MedCon"
-#define XMEDCON_DATE     "17-May-2009"
-#define XMEDCON_VERSION  "0.10.5"
-#define XMEDCON_LIBVERS  "(X)MedCon 0.10.5 by Erik Nolf"
+#define XMEDCON_DATE     "15-Sep-2010"
+#define XMEDCON_VERSION  "0.10.7"
+#define XMEDCON_LIBVERS  "(X)MedCon 0.10.7 by Erik Nolf"
 
 /* Define if format enabled */
 #define MDC_INCLUDE_ACR   1
@@ -51,17 +51,17 @@
 #define MDC_INCLUDE_DICM  1
 #define MDC_INCLUDE_PNG   1
 #define MDC_INCLUDE_NIFTI 1
-#define MDC_INCLUDE_TPC   0    /* TPC ecat7 write */
+#define MDC_INCLUDE_TPC   1    /* TPC ecat7 write */
 
 /* Define some machine dependencies */
-#define MDC_WORDS_BIGENDIAN  0
+#define MDC_WORDS_BIGENDIAN  1
 #define MDC_SIZEOF_SHORT     2
 #define MDC_SIZEOF_INT       4
-#define MDC_SIZEOF_LONG      8
+#define MDC_SIZEOF_LONG      4
 #define MDC_ENABLE_LONG_LONG 0
 
 #if MDC_ENABLE_LONG_LONG
-#define MDC_SIZEOF_LONG_LONG 
+#define MDC_SIZEOF_LONG_LONG 8
 #endif
 
 
